@@ -22,5 +22,5 @@ class PostJobRequest(RoaRequest):
 
 	def __init__(self):
 		RoaRequest.__init__(self, 'BatchCompute', '2013-01-11', 'PostJob')
-		self.set_uri_pattern(self, '/jobs')
-		self.set_method(self, 'POST')
\ No newline at end of file
+		self.set_uri_pattern('/jobs')
+		self.set_method('POST')
\ No newline at end of file
