@@ -22,8 +22,8 @@ class StartJobRequest(RoaRequest):
 
 	def __init__(self):
 		RoaRequest.__init__(self, 'BatchCompute', '2013-01-11', 'StartJob')
-		self.set_uri_pattern(self, '/jobs/[ResourceName]?Action=Start')
-		self.set_method(self, 'PUT')
+		self.set_uri_pattern('/jobs/[ResourceName]?Action=Start')
+		self.set_method('PUT')
 
 	def get_ResourceName(self):
 		return self.get_path_params().get('ResourceName')
