@@ -22,8 +22,8 @@ class PutJobRequest(RoaRequest):
 
 	def __init__(self):
 		RoaRequest.__init__(self, 'BatchCompute', '2015-06-30', 'PutJob')
-		self.set_uri_pattern(self, '/jobs/[ResourceName]/Priority')
-		self.set_method(self, 'PUT')
+		self.set_uri_pattern('/jobs/[ResourceName]/Priority')
+		self.set_method('PUT')
 
 	def get_ResourceName(self):
 		return self.get_path_params().get('ResourceName')
